@@ -46,14 +46,11 @@ public:
         NoUpdate,       /**< do not send mail to attendee */
         Edit            /**< open composer for attendee */
     };
-    explicit IndividualMailDialog(const QString &question,
-                                  const KCalCore::Attendee::List &attendees,
-                                  const KGuiItem &buttonYes, const KGuiItem &buttonNo,
-                                  QWidget *parent = nullptr);
-    virtual ~IndividualMailDialog();
+    explicit IndividualMailDialog(const QString &question, const KCalCore::Attendee::List &attendees, const KGuiItem &buttonYes, const KGuiItem &buttonNo, QWidget *parent = nullptr);
+    ~IndividualMailDialog() override;
 
-    KCalCore::Attendee::List editAttendees() const;
-    KCalCore::Attendee::List updateAttendees() const;
+    Q_REQUIRED_RESULT KCalCore::Attendee::List editAttendees() const;
+    Q_REQUIRED_RESULT KCalCore::Attendee::List updateAttendees() const;
 
 private:
     void updateButtonState();
